<?php
/**
 * A Console template engine class
 *
 * @author		Roland Haeder <webmaster@ship-simu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2012 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.ship-simu.org
 * @todo		This template engine does not make use of setTemplateType()
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
class ConsoleTemplateEngine extends BaseTemplateEngine implements CompileableTemplate {
	/**
	 * Protected constructor
	 *
	 * @return	void
	 */
	protected function __construct () {
		// Call parent constructor
		parent::__construct(__CLASS__);
	}

	/**
	 * Creates an instance of the class TemplateEngine and prepares it for usage
	 *
	 * @return	$templateInstance		An instance of TemplateEngine
	 * @throws	BasePathIsEmptyException		If the provided $templateBasePath is empty
	 * @throws	InvalidBasePathStringException	If $templateBasePath is no string
	 * @throws	BasePathIsNoDirectoryException	If $templateBasePath is no
	 *											directory or not found
	 * @throws	BasePathReadProtectedException	If $templateBasePath is
	 *											read-protected
	 */
	public static final function createConsoleTemplateEngine () {
		// Get a new instance
		$templateInstance = new ConsoleTemplateEngine();

		// Get the application instance from registry
		$applicationInstance = Registry::getRegistry()->getInstance('app');

		// Determine base path
		$templateBasePath = $templateInstance->getConfigInstance()->getConfigEntry('application_base_path') . $applicationInstance->getRequestInstance()->getRequestElement('app') . '/';

		// Is the base path valid?
		if (empty($templateBasePath)) {
			// Base path is empty
			throw new BasePathIsEmptyException($templateInstance, self::EXCEPTION_UNEXPECTED_EMPTY_STRING);
		} elseif (!is_string($templateBasePath)) {
			// Is not a string
			throw new InvalidBasePathStringException(array($templateInstance, $templateBasePath), self::EXCEPTION_INVALID_STRING);
		} elseif (!is_dir($templateBasePath)) {
			// Is not a path
			throw new BasePathIsNoDirectoryException(array($templateInstance, $templateBasePath), self::EXCEPTION_INVALID_PATH_NAME);
		} elseif (!is_readable($templateBasePath)) {
			// Is not readable
			throw new BasePathReadProtectedException(array($templateInstance, $templateBasePath), self::EXCEPTION_READ_PROTECED_PATH);
		}

		// Set the base path
		$templateInstance->setTemplateBasePath($templateBasePath);

		// Set template extensions
		$templateInstance->setRawTemplateExtension($templateInstance->getConfigInstance()->getConfigEntry('raw_template_extension'));
		$templateInstance->setCodeTemplateExtension($templateInstance->getConfigInstance()->getConfigEntry('code_template_extension'));

		// Absolute output path for compiled templates
		$templateInstance->setCompileOutputPath($templateInstance->getConfigInstance()->getConfigEntry('base_path') . $templateInstance->getConfigInstance()->getConfigEntry('compile_output_path'));

		// Return the prepared instance
		return $templateInstance;
	}
}

// [EOF]
?>
